@@ -10,7 +10,11 @@ key = map(lambda idx:
               keychars[int(random.random() * len(keychars))],
           range(4))
 key = string.join(key, '')
-s = _pickey.GetPNG(key, 160, 48, dot_limit = 32)
+fontpathes = ['/usr/share/fonts/corefonts/arialbd.ttf',
+              '/usr/share/fonts/corefonts/courbd.ttf',
+              '/usr/share/fonts/corefonts/timesbd.ttf']
+s = _pickey.GetPNG(key, 160, 48, dot_limit = 32,
+                   fontpathes = string.join(fontpathes, '  \t\n'))
 f = file('x.png', 'w')
 f.write(s)
 f.close()
